@@ -321,7 +321,7 @@ class RexsterClient(Client):
         self.request = self.request_class(self.config, self.type_system.content_type)
 
         # Rexster supports Gremlin so include the Gremlin-Groovy script library
-        self.scripts = GroovyScripts() 
+        self.scripts = GroovyScripts(self.config) 
 
         # Also include the Rexster-specific Gremlin-Groovy scripts
         scripts_file = get_file_path(__file__, "gremlin.groovy")
@@ -350,7 +350,9 @@ class RexsterClient(Client):
         :rtype: RexsterResponse
 
         """
-        params = dict(script=script,params=params)
+        params = dict(script=script, params=params)
+        if self.config.server_scripts is True:
+            params["load"] = self.scripts.namespace_map.keys() 
         return self.request.post(gremlin_path,params)
 
 
